@@ -42,7 +42,7 @@ def strip_comments(query) -> str:
     :param query:
     :return:
     """
-    return re.sub('(([\s-]+-).+\n)|(([\s\#]+\#).+\n)', ' ', query)
+    return re.sub('((\n)+(\s)*(--)(.+\n))|((\n)+(\s)*(\#)(.+\n))', ' ', query)
 
 
 def wrap_variables(query, encoding_character='', wrap_character="'", encoded=False):
