@@ -65,6 +65,7 @@ def label_input(variable_set, query_ast):
                 variables[variable] = dict(
                     name=clean_name, display_name=display_name.split('.')[-1], default_value=default_value,
                     type=data_type, allows_list=allows_list, full_string=group,
+                    is_literal=True if not partial_string else False,
                     locations=location,
                     is_partial_string=partial_string
                 )
@@ -183,6 +184,26 @@ def find_first_node(node_key, parse_result):
     return None
 
 
+def to_date_math_call(tokens):
+    # ARRANGE INTO {op: params} FORMAT
+    op = tokens["op"].lower()
+    op = binary_ops.get(op, op)
+    params = scrub(tokens["params"])
+    if not params:
+        params = {}
+    if scrub(tokens["ignore_nulls"]):
+        ignore_nulls = True
+    else:
+        ignore_nulls = None
+
+    return ParseResults(
+        tokens.type,
+        tokens.start,
+        tokens.end,
+        [{op: params, "ignore_nulls": ignore_nulls}],
+    )
+
+
 class Parser(object):
     parser = None
     known_types = known_types
@@ -230,7 +251,6 @@ class Parser(object):
                 + Optional(ELSE + expr("else"))
                 + END
         ).addParseAction(to_case_call)
-
         # SWITCH
         switch = (
                 CASE
@@ -251,7 +271,7 @@ class Parser(object):
             for d in self.durations.keys()
         ]).set_parser_name("duration")("params")
 
-        duration = (realNum | intNum | placeholder_pattern)("params") + _standard_time_intervals
+        duration = (realNum | intNum | ident)("params") + _standard_time_intervals
 
         interval = (
                 INTERVAL + ("'" + delimitedList(duration) + "'" | duration)
